@@ -1,7 +1,10 @@
 package t::app::Main::Result::Object;
 use base qw/DBIx::Class::Core/;
 __PACKAGE__->table('object');
-__PACKAGE__->add_columns(qw/ objectid name /);
+__PACKAGE__->add_columns('objectid',
+                         { data_type => "integer", is_auto_increment => 1, is_nullable => 0 },
+                         'name',
+                         {data_type => 'varchar', is_nullable => 0});
 __PACKAGE__->set_primary_key('objectid');
 __PACKAGE__->load_components(qw/ Result::Validation /);
 
